==> jc-1.4.0.tar.gz: gnu/java/text/WordBreakIterator.h <==
// public class gnu.java.text.WordBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class 682729779b71e2ef gnu_java_text_WordBreakIterator
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header gnu_java_text_BaseBreakIterator

#include "gnu/java/text/BaseBreakIterator.h"

#ifndef _JC_gnu_java_text_WordBreakIterator_H_
#define _JC_gnu_java_text_WordBreakIterator_H_

// Forward structure declarations
struct _jc_gnu_java_text_WordBreakIterator$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_text_WordBreakIterator$sub_refs	_jc_gnu_java_text_WordBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_WordBreakIterator$sub_nonrefs	_jc_gnu_java_text_WordBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_WordBreakIterator$refs	_jc_gnu_java_text_WordBreakIterator$refs;
typedef struct _jc_gnu_java_text_WordBreakIterator$nonrefs	_jc_gnu_java_text_WordBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_WordBreakIterator$object	_jc_gnu_java_text_WordBreakIterator$object;

typedef const struct _jc_gnu_java_text_WordBreakIterator$vmethods	_jc_gnu_java_text_WordBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_WordBreakIterator$vtable	_jc_gnu_java_text_WordBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_WordBreakIterator$vtype	_jc_gnu_java_text_WordBreakIterator$vtype;

// Constructors
extern void _jc_gnu_java_text_WordBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *);
extern void _jc_gnu_java_text_WordBreakIterator$method$_init$d0a4bb002c352dba(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, struct _jc_gnu_java_text_WordBreakIterator$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_text_WordBreakIterator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *);
extern jboolean _jc_gnu_java_text_WordBreakIterator$method$isHan$c40d4fe60c378834(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar);
extern jboolean _jc_gnu_java_text_WordBreakIterator$method$isHira$2ee180fae4fb3c27(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar);
extern jboolean _jc_gnu_java_text_WordBreakIterator$method$isKata$123dbbe43d9487e1(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar);
extern jint _jc_gnu_java_text_WordBreakIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *);
extern jint _jc_gnu_java_text_WordBreakIterator$method$previous$9ade62028ea90005(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$isHan$c40d4fe60c378834;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$isHira$2ee180fae4fb3c27;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$isKata$123dbbe43d9487e1;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$next$0a35667a0e69bb19;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$previous$9ade62028ea90005;

// Virtual methods structure
struct _jc_gnu_java_text_WordBreakIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *);
	jboolean	(*isHan$c40d4fe60c378834)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar);
	jboolean	(*isHira$2ee180fae4fb3c27)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar);
	jboolean	(*isKata$123dbbe43d9487e1)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar);
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *);
	jint	(*previous$9ade62028ea90005)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *);
};

// Vtable
struct _jc_gnu_java_text_WordBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
	_jc_gnu_java_text_WordBreakIterator$vmethods	gnu_java_text_WordBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_WordBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_WordBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_WordBreakIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_text_WordBreakIterator$refs {
    _jc_gnu_java_text_WordBreakIterator$sub_refs	gnu_java_text_WordBreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_WordBreakIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_WordBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
    _jc_gnu_java_text_WordBreakIterator$sub_nonrefs	gnu_java_text_WordBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_WordBreakIterator$object {
	_jc_gnu_java_text_WordBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_WordBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_WordBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_WordBreakIterator$vtype _jc_gnu_java_text_WordBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_WordBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_WordBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_WordBreakIterator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/text/WordBreakIterator.h <==
// public class gnu.java.text.WordBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class 682729779b71e2ef gnu_java_text_WordBreakIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header gnu_java_text_BaseBreakIterator

#include "gnu/java/text/BaseBreakIterator.h"

#ifndef _JC_gnu_java_text_WordBreakIterator_H_
#define _JC_gnu_java_text_WordBreakIterator_H_

// Forward structure declarations
struct _jc_gnu_java_text_WordBreakIterator$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_text_WordBreakIterator$sub_refs	_jc_gnu_java_text_WordBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_WordBreakIterator$sub_nonrefs	_jc_gnu_java_text_WordBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_WordBreakIterator$refs	_jc_gnu_java_text_WordBreakIterator$refs;
typedef struct _jc_gnu_java_text_WordBreakIterator$nonrefs	_jc_gnu_java_text_WordBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_WordBreakIterator$object	_jc_gnu_java_text_WordBreakIterator$object;

typedef const struct _jc_gnu_java_text_WordBreakIterator$vmethods	_jc_gnu_java_text_WordBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_WordBreakIterator$vtable	_jc_gnu_java_text_WordBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_WordBreakIterator$vtype	_jc_gnu_java_text_WordBreakIterator$vtype;

// Constructors
extern void _jc_gnu_java_text_WordBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_text_WordBreakIterator$method$_init$d0a4bb002c352dba(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, struct _jc_gnu_java_text_WordBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_text_WordBreakIterator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_WordBreakIterator$method$isHan$c40d4fe60c378834(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_WordBreakIterator$method$isHira$2ee180fae4fb3c27(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_WordBreakIterator$method$isKata$123dbbe43d9487e1(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_WordBreakIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_WordBreakIterator$method$previous$9ade62028ea90005(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$isHan$c40d4fe60c378834;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$isHira$2ee180fae4fb3c27;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$isKata$123dbbe43d9487e1;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$next$0a35667a0e69bb19;
extern _jc_method _jc_gnu_java_text_WordBreakIterator$method_info$previous$9ade62028ea90005;

// Virtual methods structure
struct _jc_gnu_java_text_WordBreakIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*isHan$c40d4fe60c378834)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jboolean	(*isHira$2ee180fae4fb3c27)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jboolean	(*isKata$123dbbe43d9487e1)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*previous$9ade62028ea90005)(_jc_env *, struct _jc_gnu_java_text_WordBreakIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_text_WordBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
	_jc_gnu_java_text_WordBreakIterator$vmethods	gnu_java_text_WordBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_WordBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_WordBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_WordBreakIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_text_WordBreakIterator$refs {
    _jc_gnu_java_text_WordBreakIterator$sub_refs	gnu_java_text_WordBreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_WordBreakIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_WordBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
    _jc_gnu_java_text_WordBreakIterator$sub_nonrefs	gnu_java_text_WordBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_WordBreakIterator$object {
	_jc_gnu_java_text_WordBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_WordBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_WordBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_WordBreakIterator$vtype _jc_gnu_java_text_WordBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_WordBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_WordBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_WordBreakIterator_H_ */
